
public bool CreateGridLayout()
{
    gridTable1.Columns.Clear();
    gridTable1.ItemsSource = null;

    TextColumn col = new TextColumn();
    col.Key = "concepts";
    col.HeaderText = "Concepts";
    gridTable1.Columns.Add(col);

    // all respondent groups
    for (int iRG = 1; iRG <= _selRespGroups.Count; iRG++)
    {
        GroupColumn colGroup = null;
        if (_selRespGroups.Count > 1)
        {
            colGroup = new GroupColumn();
            colGroup.Key = "rg" + iRG.ToString();
            colGroup.HeaderText = _selRespGroups[iRG - 1].Name;
        }
        
        // all facts
        for (int iF = 1; iF <= _selFacts.Count; iF++)
        {
            col = new TextColumn();
            col.Key = "rg" + iRG.ToString() + "fct" + iF.ToString();
            col.HeaderText = _selFacts[iF - 1].Name;
            
            if (_selRespGroups.Count == 1)
                gridTable1.Columns.Add(col);
            else
                colGroup.Columns.Add(col);
        }
        if (_selRespGroups.Count > 1)
            gridTable1.Columns.Add(colGroup);
    }
    
    return true;
}

public DataView GetDataforGrid()
{
    if (_selRespGroups.Count == 0 ||_selFacts.Count == 0 || _ana.Scenarios[0] == null || _ana.Scenarios[0].Concepts.Count == 0)
        return null;

    var t = new DataTable();

    // 1. Create columns
    t.Columns.Add(new DataColumn("concepts"));

    // all respondent groups
    for (int iRG = 1; iRG <= _selRespGroups.Count; iRG++)
    {
        // all facts
        for (int iF = 1; iF <= _selFacts.Count; iF++ )
        {
            DataColumn col = new DataColumn("rg" + iRG.ToString() + "fct" + iF.ToString());
            t.Columns.Add(col);
        }
    }

    // 2. Create rows
    String sIndent = "";
    foreach (CConcept cpt in _shownConcepts)
    {
        var newRow = t.NewRow();
        newRow[0] = cpt.Name;
        t.Rows.Add(newRow);
        if (cpt is CConceptGroup)
            AddRowsForChildConcepts(sIndent, (CConceptGroup) cpt, t);
    }

    // 3. Fill rows with data
    CScenario scenario = (isCompareMode() ? _ana.Scenarios[1] : _ana.Scenarios[0]);
    // In CompareMode the temporary scenario is the second one.

    CConceptList allConcepts = scenario.getAllConcepts();
    for (var r = 0; r < allConcepts.Count; r++)
    {
        CConcept cpt = allConcepts[r];
        var row = t.Rows[r];

        // all respondent groups
        var c = 1;
        for (int iRG = 0; iRG < _ana.Respgroups.Count; iRG++)
        {
            CRespondentGroup respgroup = _ana.Respgroups[iRG];

            CalcSettings calcsettings = _anacalc.lstCalcSettings.Where(cs => cs.Input.RespGroup == respgroup && cs.Input.Scenario == scenario).FirstOrDefault();
            CalcResult calcresult = null;
            if (calcsettings != null)
                calcresult = calcsettings.Result;

            // all facts
            for (int iF = 0; iF < _selFacts.Count; iF++, c++)
            {
                double val = calcresult.getValue(cpt, _selFacts[iF]);
                row[c] = getFormattedValue(_selFacts[iF], val);
            }
        }
    }

    return t.DefaultView;
}

private bool AddRowsForChildConcepts(String sIndent, CConceptGroup cptGroup, DataTable table)
{
    if (!(cptGroup is CConceptGroup))
        return false;

    sIndent += "  ";
    foreach (CConcept cpt in cptGroup.Concepts)
    {
        var newRow = table.NewRow();
        newRow[0] = sIndent + cpt.Name;
        table.Rows.Add(newRow);
        if (cpt is CConceptGroup)
            AddRowsForChildConcepts(sIndent, (CConceptGroup) cpt, table);
    }

    return true;
}
